/**
 * QGraph
 * by Daniel Steinbock <steinbock@stanford.edu>
 * 
 * Graphing movement data for QMovement
 *
 */ 

import toxi.math.*;


class QGraph {
  int[] differenceData;
  int[][] movementGraphData;
  int[][] movementGraphDataAvg;
  ScaleMap logMap;

  QGraph() {
    differenceData = qdata.getDifferenceData();
    movementGraphData = qdata.getMovementGraphData();
    movementGraphDataAvg = qdata.getMovementGraphDataAvg();
    logMap = new ScaleMap(0,1,434,320);
    logMap.setMapFunction(new ExponentialInterpolation());
  }

  void draw() {
    
    fill(0,0,30);
    rect(0,320,1152,115);
    noFill();
    
    //movementSumMax = 0;  // reset movementSumMax
    for(int c = 0; c < bodyStack.size(); ++c) {
      beginShape();
      stroke(100,200,240);
      for(int i = 0; i<movementGraphData[c].length;i++){
        if(computeMovingAverage(c, i) != 0) {
    //      vertex(i,map(log(movementGraphDataAvg[c][i]),0,log(movementSumMax),435,320));
//          vertex(c*movementGraphData[c].length + i,map(constrain(movementGraphDataAvg[c][i],0,movementSumMax),0,movementSumMax,434,320));
//          vertex(c*movementGraphData[c].length + i,map(log(pow(movementGraphDataAvg[c][i],2)),0,log(pow(movementSumMax,2)),434,320));
          logMap.setInputRange(0,log(movementSumMax));
          vertex(c*movementGraphData[c].length + i,(float)logMap.getMappedValueFor(log(movementGraphDataAvg[c][i])));
        }
        else {
          vertex(c*movementGraphData[c].length + i,435);
        }
      }
      endShape();
      // move the just-graphed data over one
      for(int i = 1; i<movementGraphData[c].length;i++){
        movementGraphData[c][i-1] = movementGraphData[c][i];
//        if( movementGraphData[c][i] > movementSumMax) movementSumMax = movementGraphData[c][i];
      }
      // add the new data point to the end of the array (wait for a couple of frames before recording)
      if( movie.frame() > (analysisStartFrame + skipFirstFrames)) {
        movementGraphData[c][movementGraphData[c].length-1] = differenceData[c];
        if( differenceData[c] > movementSumMax) movementSumMax = differenceData[c];
      }
      // print graph borders
      stroke(0,60,100);
      int x1 = (c+1) * (1152 / bodyStack.size());
      line(x1, 320, x1, 435);
    }
  }
  
  int computeMovingAverage(int c, int i) {
    if(i < ui.avgWindow){          // if point i is one of the left-most
      for(int j=0;j < ui.avgWindow*2;++j){
        movementGraphDataAvg[c][i] += movementGraphData[c][j];
      }
    }
    else if(i > movementGraphData[c].length - (ui.avgWindow + 1)){        // if this point i is one of the right-most
      for(int j=0;j < ui.avgWindow*2;++j){
        movementGraphDataAvg[c][i] += movementGraphData[c][movementGraphData[c].length - 1 - j];
      }
    }
    else {
      movementGraphDataAvg[c][i] = movementGraphData[c][i];
      for(int j=1;j <= ui.avgWindow;++j){
        movementGraphDataAvg[c][i] += movementGraphData[c][i + j];
        movementGraphDataAvg[c][i] += movementGraphData[c][i - j];
      } 
    }  
    movementGraphDataAvg[c][i] = round(movementGraphDataAvg[c][i] / (ui.avgWindow*2 + 1));    // moving average
  
    return movementGraphDataAvg[c][i]; 
  }

}
