/**
 * QOutput
 * by Daniel Steinbock <steinbock@stanford.edu>
 * 
 * Writes movement data to a file for QMovement
 * Column 1 = frame number
 * Column 2 = timecode
 * Column 3 = whole movie frame difference
 * Column 4 and beyond = per-body movement data
 *
 */ 


class QOutput {
  final String outputFilename = videoFilename + ".csv";
  PrintWriter fileOutput;
  int count = 0;
  
  QOutput(int numBodies) {
    fileOutput = createWriter(outputFilename);

    fileOutput.print("Count,Frame,Time,Total,");
    for(int c = 0; c < numBodies; ++c) {
      fileOutput.print("Body" + ((QBody)bodyStack.get(c)).L + "-" + ((QBody)bodyStack.get(c)).R + ",");
    }
    fileOutput.print("\n");
  }

  void writeData() {
    int[] differenceData = qdata.getDifferenceData();
  
    fileOutput.print(count + "," + currFrame + "," + movie.time() + "," + qdata.getMovementTotal() + ",");
    for(int c = 0; c < bodyStack.size(); ++c) {
      fileOutput.print(differenceData[c] + ","); 
      //print(differenceData[c] + ","); 
    }
    fileOutput.print("\n");
    ++count;
  }


  public void finish(){
    // write Movement Ceiling as last row
    fileOutput.print("Ceiling:,,,,");
    for(int c = 0; c < bodyStack.size(); ++c) {
      fileOutput.print(((QBody)bodyStack.get(c)).getCeiling() + ",");
    }

    fileOutput.flush(); // Write the remaining data
    fileOutput.close(); // Finish the file
  }


}

