/**
 * QUI
 * by Daniel Steinbock <steinbock@stanford.edu>
 * 
 * UI controls for QMovement
 *
 */ 

import controlP5.*;

class QUI {

  ControlP5 controlP5;
  Button movingAvgButton;
  RadioButton colorRadio;
  Textfield startTime;
  Textfield endTime;

  int colorPalette = 1;    // currently 0 = heat, 1 = green, 2 = diff
  int minDiffThreshold = 48;
  float minDiffSumThreshold = 0.0;
  int avgWindow = 1;
 
  QUI(ControlP5 theControl) {
    controlP5 = theControl;
    controlP5.addButton("ShowBackground?",1,400,height-40,15,15).setId(2);
    controlP5.addSlider("AvgWindow",0,100,avgWindow,200,height-40,100,15).setId(3);
    controlP5.addSlider("Threshold",0,200,minDiffThreshold,20,height-20,100,15).setId(4);
    controlP5.addSlider("SumThreshold",0.0,0.5,minDiffSumThreshold,20,height-40,100,15).setId(5);
    controlP5.addButton("ShowMovie?",1,300,height-20,15,15).setId(6);
//    controlP5.addButton("ShowGraph?",1,400,height-20,15,15).setId(7);
    controlP5.addButton("ShowHistory?",1,400,height-20,15,15).setId(8);
    colorRadio = controlP5.addRadioButton("colorPaletteRadio",500,height-42);
    
    startTime = controlP5.addTextfield("Start Time",100,160,200,20);
    endTime = controlP5.addTextfield("End Time",100,200,200,20);
//    frameRateField = controlP5.addTextfield("Frame Rate",100,200,200,20);
    startTime.setId(9);
    endTime.setId(10);
    startTime.setFocus(true);
    controlP5.addButton("submit",0,100,240,80,20).setId(11);

    controlP5.addTextfield("STATUS",700,height-40,250,15).setId(1);
    setStatus("Welcome to QMovement.");
    
    colorRadio.addItem("heat",0);
    colorRadio.addItem("green",1);
    colorRadio.addItem("diff",2);
  } 
  
  public void dispatch(ControlEvent theEvent) {
    if(theEvent.isGroup()) {
      if(theEvent.group() instanceof RadioButton) {
        colorPalette = int(theEvent.group().value());
        setStatus("Palette = " + theEvent.group().name());
      }
    } 
    else {
      switch(theEvent.controller().id()) {
        case(1):
          // status
          break;
        case(2):
          hideBackground = !hideBackground;
          setStatus("Background = " + hideBackground);
          break;
        case(3):
          avgWindow = (int)(theEvent.controller().value());
          setStatus("Avg Window = " + avgWindow);
          break;  
        case(4):
          minDiffThreshold = (int)(theEvent.controller().value());
          setStatus("Threshhold = " + minDiffThreshold);
          break;  
        case(5):
          minDiffSumThreshold = (int)(theEvent.controller().value());
          setStatus("Threshold Sum = " + minDiffSumThreshold);
          break;  
        case(6):
          showMovie = !showMovie;
          setStatus("Show movie = " + showMovie);
          break;
        case(7):
          showGraph = !showGraph;
          setStatus("Show graph = " + showGraph);
          break;
        case(8):
          showHistory = !showHistory;
          setStatus("Show history = " + showHistory);
          break;
        case(9):
          analysisStartTime = Float.parseFloat(theEvent.controller().stringValue());
          if( analysisStartTime != 0 ){
            mov.jump(analysisStartTime);
            analysisStartFrame = mov.frame();
            mov.goToBeginning();
          }
          else
            analysisStartFrame = 0;
          println("Starting analysis frame = " + analysisStartFrame);
          break;
        case(10):
          analysisEndTime = Float.parseFloat(theEvent.controller().stringValue());
          if( analysisEndTime != 0 ){
            mov.jump(analysisEndTime);
            analysisEndFrame = mov.frame();
            mov.goToBeginning();
          }
          else
            analysisEndFrame = int(mov.length() - 1);
          println("Ending analysis frame = " + analysisEndFrame);
          break;
        case(11):
          startTime.submit();
          endTime.submit();
//          selectionLoop = new PImage[int((analysisEndFrame - analysisStartFrame) / numLoopFrames) + 1];        // only loop on section selected for analysis
          loopFramesStepSize = int((analysisEndFrame - analysisStartFrame) / loopFramesNum);
          selectionLoop = new PImage[loopFramesNum + 1];        // only loop on section selected for analysis
          startTime.hide();
          endTime.hide();
          theEvent.controller().hide();
          initStartEndTimes = false;
          break;
      }
    }
  }

  public void setStatus(String newStatus) {
    ((Textfield)controlP5.controller("STATUS")).setValue(newStatus);
  }
  
}
